@@ -235,6 +235,17 @@ impl UserDefined {
     }
 }
 
+// Macros
+#[macro_export]
+/// Creates a vector of elements instead of creating `vec![Element::from(foo)]`
+macro_rules! elements {
+   ($($x:expr),+) => ({
+       let mut v = Vec::new();
+       $( v.push(Element::from($x)); )+
+       v
+   });
+}
+
 // Trait Implementations //
 impl Convert for Part {
     fn to_latex_string(&self) -> String {
